package com.oracle.coherence.swingdemo;

import java.util.HashMap;
import java.util.Random;

import com.oracle.coherence.swingdemo.model.Position;
import com.tangosol.net.CacheFactory;
import com.tangosol.net.NamedCache;
import com.tangosol.util.extractor.ReflectionExtractor;

/**
 * <p>A simple console application to randomly create a number of {@link Position}s
 * in a Coherence {@link NamedCache}.</p>
 *
 * @author Brian Oliver (brian.oliver@oracle.com)
 */
public class CreatePositions {

	private final static int NR_POSITIONS_TO_CREATE = 100000;

	/**
	 * @param args
	 */
	@SuppressWarnings("unchecked")
	public static void main(String[] args) {
		NamedCache positionsCache = CacheFactory.getCache("positions");

		System.out.println("Adding Indexes...");
		positionsCache.addIndex(new ReflectionExtractor("getSymbol"), true, null);
		positionsCache.addIndex(new ReflectionExtractor("getValue"), false, null);

		System.out.printf("Creating %d Positions...\n", NR_POSITIONS_TO_CREATE);
		Random random = new Random();
	    String[] symbols = {"ORCL", "JAVA", "MSFT", "GOOG", "AAPL"};
	    HashMap<Integer, Position> positions = new HashMap<Integer, Position>();

	    for (int i = 0; i < NR_POSITIONS_TO_CREATE; i++) {
	    	//create a random position
	    	String symbol = symbols[random.nextInt(symbols.length)];
	    	int amount = random.nextInt(1000);
	    	double price = random.nextInt(10);

	    	positions.put(i, new Position(i, symbol, amount, price));
        }

	    positionsCache.putAll(positions);

	    System.out.printf("Creation Complete! (Cache contains %d positions)\n", positionsCache.size());
	}
}
