package com.oracle.coherence.util.tuples;

import java.io.DataInput;
import java.io.DataOutput;
import java.io.IOException;

import com.tangosol.util.ExternalizableHelper;

/**
 * A {@link Tuple} where the number of values is set at construction time (not at compile time)
 */
public class TupleN implements Tuple {

	private static final long serialVersionUID = -3998104715270106175L;

	//the values in the tuple
    private Object[] values;


    public TupleN() { 
            //for ExternalizableLite
    }

    
    public TupleN(Tuple x, Tuple y) {
    	values = new Object[x.size() + y.size()];
    	int i = 0;
    	for (int j = 0; j < x.size();) 
    		values[i++] = x.get(j++);
    	for (int j = 0; j < y.size();) 
    		values[i++] = y.get(j++);
    }
    

    public TupleN(Object... values) {
            this.values = values;
    }


    public int size() {
            return values.length;
    }


    public Object get(int index) throws IndexOutOfBoundsException {
            return values[index];
    }


    @Override
    public String toString() {
            StringBuilder result = new StringBuilder("TupleN(");
            for (int i = 0; i < size(); i++) {
                    result.append(values[i].toString());
                    if (i < size()-1)
                            result.append(", ");
            }
            return result.append(")").toString();
    }


    public void readExternal(DataInput dataInput) throws IOException {
            int nrValues = ExternalizableHelper.readInt(dataInput);
            values = new Object[nrValues];
            for (int i=0; i< nrValues; i++)
                    values[i] = ExternalizableHelper.readObject(dataInput);
    }


    public void writeExternal(DataOutput dataOutput) throws IOException {
            ExternalizableHelper.writeInt(dataOutput, values.length);
            for (Object value : values)
                    ExternalizableHelper.writeObject(dataOutput, value);
    }

}
